@@ -5,6 +5,7 @@ use feature qw( say );
 use IO::All;
 use Data::Dumper;
 $Data::Dumper::Sortkeys = 1;
+use File::Basename;
 use FindBin;
 use lib "$FindBin::Bin/../lib";
 use FSM::Basic;
@@ -16,7 +17,12 @@ my %to_subst = (
     __PROMPT__   => 'User> '
 );
 
-my $file_def = shift;
+my $file_def= shift;;
+
+my $basename = basename $0 , '.pl';
+
+$file_def= "$FindBin::Bin/$basename.json"if ( -e  "$FindBin::Bin/$basename.json" && !$file_def);
+
 my $json     = io( $file_def )->slurp;
 foreach my $subst ( keys %to_subst )
 {
@@ -24,7 +30,7 @@ foreach my $subst ( keys %to_subst )
 }
 
 my $states       = from_json( $json );
-say Dumper($states);
+#say Dumper($states);
 my $history_file = glob( '~/.bash.history' );
 my $prompt       = '> ';
 my $line;
