@@ -3,18 +3,19 @@ package FSM::Basic;
 use 5.006;
 use strict;
 use warnings;
-
+use Carp;
+use Data::Dumper;
 =head1 NAME
 
 FSM::Basic -  Finite state machine using HASH as state definitions
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =cut
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 =head1 SYNOPSIS
 
@@ -236,12 +237,37 @@ sub run
     #    }
 }
 
-sub edit
-{
-    my ( $self, $in ) = @_;
-
-    return $self;
-}
+#sub edit
+#{
+#    my ( $self, $in ) = @_;
+#
+#    return $self;
+#}
+#
+#sub crawl_states
+#{
+#    my ( $self, $in ) = @_;
+#    my $state;
+#    warn $in;
+#    warn Dumper($self->{states_list}{$in});
+#    if ( exists $self->{states_list}{$self->{state}}{expect}{$in} )
+#        {
+#            $state = $self->{states_list}{$self->{state}}{expect}{$in};
+#        }
+#        else
+#        {
+#            foreach my $key ( keys %{$self->{states_list}{$self->{state}}{expect}} )
+#            {
+#                if ( $in =~ /$key/ )
+#                {
+#                    $state = $self->{states_list}{$self->{state}}{expect}{$key};
+#                }
+#            }
+#        }
+#        
+#
+#    return $state;
+#}
 
 =head1 EXAMPLE
 
